==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/table_factory/table_factory_server.dart <==
// 🎯 Dart imports:
import "dart:math";

// 🐦 Flutter imports:
import "package:flutter/material.dart";
import "package:flutter/scheduler.dart";

// 📦 Package imports:
import "package:collection/collection.dart";
import 'package:verttice_models/verttice_models.dart';

// 🌎 Project imports:
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';
import '../data_factory_index.dart';
import 'table_frame_server.dart';

class TableFactoryServer extends StatefulWidget {
  final List<Map<String, dynamic>> data;
  final List<FormItem> columns;
  final String title;
  final void Function(Map<String, dynamic>? rowData)? rowPressCallback;
  final String uniqueIdField;
  final Widget? topBarWidget;
  final double? topBarPercentageHeight;
  final bool enableCopyButton;
  final List<Widget>? tableActions;
  final double? tableActionPercentageWidth;
  final void Function(List<Map<String, dynamic>>)? selectedListCallback;
  final Function(List<FilterField>) onFilterChanged;
  final Function(String)? onSearchChanged;
  final void Function({
    required String field,
    required bool asc,
  }) onSortChanged;

  const TableFactoryServer({
    Key? key,
    required this.data,
    required this.columns,
    required this.uniqueIdField,
    required this.onFilterChanged,
    required this.onSortChanged,
    this.title = "Table",
    this.rowPressCallback,
    this.enableCopyButton = true,
    this.onSearchChanged,
    this.topBarWidget,
    this.topBarPercentageHeight,
    this.tableActions,
    this.tableActionPercentageWidth,
    this.selectedListCallback,
  }) : super(key: key);

  @override
  State<TableFactoryServer> createState() => _TableDataState();
}

class _TableDataState extends State<TableFactoryServer> {
  final double _separator = 2.0;
  late List<Map<String, dynamic>> _tableData;
  late double _topHeightPercentage;

  @override
  void initState() {
    super.initState();
    _tableData = widget.data;
    _topHeightPercentage = (widget.topBarWidget != null)
        ? min(widget.topBarPercentageHeight ?? 0.4, 0.4)
        : 0.0;
  }

  @override
  void setState(VoidCallback fn) {
    if (mounted) {
      SchedulerBinding.instance.addPostFrameCallback((_) {
        super.setState(fn);
      });
    }
  }

  @override
  void didUpdateWidget(covariant TableFactoryServer oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_tableData, widget.data)) {
      _tableData = widget.data;
    }
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      final double topPanelHeight =
          (constraints.maxHeight * _topHeightPercentage);
      return Stack(
        children: [
          SizedBox(
            height: constraints.maxHeight,
            width: constraints.maxWidth,
          ),
          AnimatedPositioned(
              duration: const Duration(milliseconds: 200),
              top: 0,
              child: (widget.topBarWidget != null)
                  ? SizedBox(
                      height: topPanelHeight,
                      width: constraints.maxWidth,
                      child: widget.topBarWidget,
                    )
                  : const SizedBox(
                      height: 0,
                      width: 0,
                    )),
          AnimatedPositioned(
            duration: const Duration(milliseconds: 200),
            top: topPanelHeight,
            height: _separator,
            width: constraints.maxWidth,
            child: MouseRegion(
                cursor: SystemMouseCursors.resizeRow,
                child: GestureDetector(
                  onPanUpdate: (DragUpdateDetails dragDetail) {
                    setState(() {
                      _topHeightPercentage =
                          dragDetail.globalPosition.dy / constraints.maxHeight;
                    });
                  },
                  child: ThemedDivider(
                    height: _separator,
                    width: constraints.maxWidth,
                  ),
                )),
          ),
          AnimatedPositioned(
            duration: const Duration(milliseconds: 300),
            top: topPanelHeight + _separator,
            height: constraints.maxHeight - (topPanelHeight + _separator),
            width: constraints.maxWidth,
            child: TableFrameServer(
              data: _tableData,
              uniqueIdField: widget.uniqueIdField,
              onSearchChanged: widget.onSearchChanged,
              onSortChanged: widget.onSortChanged,
              onFilterChanged: (Map<String, List<FilterField>> filters) {
                final List<FilterField> newFilters = [];
                for (var filter in filters.entries) {
                  if (filter.value.isNotEmpty) {
                    newFilters.add(
                      FilterField(
                        exactMatch: filter.value.first.exactMatch,
                        filterType: filter.value.first.filterType,
                        field: filter.value.first.field,
                        value: filter.value.first.filterType ==
                                    FilterTypesFF.string ||
                                filter.value.first.filterType ==
                                    FilterTypesFF.stringList
                            ? filter.value.map((e) => e.value).toList()
                            : filter.value.first.value,
                      ),
                    );
                  }
                }
                widget.onFilterChanged(newFilters);
              },
              actionPercentageWidth: widget.tableActionPercentageWidth,
              frameWidth: constraints.maxWidth,
              frameHeight:
                  constraints.maxHeight - (topPanelHeight + _separator),
              tableActions: widget.tableActions,
              enableCopyButton: widget.enableCopyButton,
              selectedListCallback: widget.selectedListCallback,
              columns: widget.columns,
              title: widget.title,
              handleSelectedRow: (Map<String, dynamic>? rowData, int rowIndex) {
                if (widget.rowPressCallback != null) {
                  widget.rowPressCallback!(rowData);
                }
              },
            ),
          )
        ],
      );
    });
  }
}

==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/data_factory/table_factory/table_factory_server.dart <==
// 🎯 Dart imports:
import "dart:math";

// 🐦 Flutter imports:
import "package:flutter/material.dart";
import "package:flutter/scheduler.dart";

// 📦 Package imports:
import "package:collection/collection.dart";
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';
import '../data_factory_index.dart';
import 'table_frame_server.dart';

class TableFactoryServer extends StatefulWidget {
  final List<Map<String, dynamic>> data;
  final List<FormItem> columns;
  final String title;
  final void Function(Map<String, dynamic>? rowData)? rowPressCallback;
  final String uniqueIdField;
  final Widget? topBarWidget;
  final double? topBarPercentageHeight;
  final bool enableCopyButton;
  final List<Widget>? tableActions;
  final double? tableActionPercentageWidth;
  final void Function(List<Map<String, dynamic>>)? selectedListCallback;
  final Function(List<FilterField>) onFilterChanged;
  final Function(String)? onSearchChanged;
  final void Function({
    required String field,
    required bool asc,
  }) onSortChanged;

  const TableFactoryServer({
    Key? key,
    required this.data,
    required this.columns,
    required this.uniqueIdField,
    required this.onFilterChanged,
    required this.onSortChanged,
    this.title = "Table",
    this.rowPressCallback,
    this.enableCopyButton = true,
    this.onSearchChanged,
    this.topBarWidget,
    this.topBarPercentageHeight,
    this.tableActions,
    this.tableActionPercentageWidth,
    this.selectedListCallback,
  }) : super(key: key);

  @override
  State<TableFactoryServer> createState() => _TableDataState();
}

class _TableDataState extends State<TableFactoryServer> {
  final double _separator = 2.0;
  late List<Map<String, dynamic>> _tableData;
  late double _topHeightPercentage;

  @override
  void initState() {
    super.initState();
    _tableData = widget.data;
    _topHeightPercentage = (widget.topBarWidget != null)
        ? min(widget.topBarPercentageHeight ?? 0.4, 0.4)
        : 0.0;
  }

  @override
  void setState(VoidCallback fn) {
    if (mounted) {
      SchedulerBinding.instance.addPostFrameCallback((_) {
        super.setState(fn);
      });
    }
  }

  @override
  void didUpdateWidget(covariant TableFactoryServer oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (!const DeepCollectionEquality().equals(_tableData, widget.data)) {
      _tableData = widget.data;
    }
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      final double topPanelHeight =
          (constraints.maxHeight * _topHeightPercentage);
      return Stack(
        children: [
          SizedBox(
            height: constraints.maxHeight,
            width: constraints.maxWidth,
          ),
          AnimatedPositioned(
              duration: const Duration(milliseconds: 200),
              top: 0,
              child: (widget.topBarWidget != null)
                  ? SizedBox(
                      height: topPanelHeight,
                      width: constraints.maxWidth,
                      child: widget.topBarWidget,
                    )
                  : const SizedBox(
                      height: 0,
                      width: 0,
                    )),
          AnimatedPositioned(
            duration: const Duration(milliseconds: 200),
            top: topPanelHeight,
            height: _separator,
            width: constraints.maxWidth,
            child: MouseRegion(
                cursor: SystemMouseCursors.resizeRow,
                child: GestureDetector(
                  onPanUpdate: (DragUpdateDetails dragDetail) {
                    setState(() {
                      _topHeightPercentage =
                          dragDetail.globalPosition.dy / constraints.maxHeight;
                    });
                  },
                  child: ThemedDivider(
                    height: _separator,
                    width: constraints.maxWidth,
                  ),
                )),
          ),
          AnimatedPositioned(
            duration: const Duration(milliseconds: 300),
            top: topPanelHeight + _separator,
            height: constraints.maxHeight - (topPanelHeight + _separator),
            width: constraints.maxWidth,
            child: TableFrameServer(
              data: _tableData,
              uniqueIdField: widget.uniqueIdField,
              onSearchChanged: widget.onSearchChanged,
              onSortChanged: widget.onSortChanged,
              onFilterChanged: (Map<String, List<FilterField>> filters) {
                final List<FilterField> newFilters = [];
                for (var filter in filters.entries) {
                  if (filter.value.isNotEmpty) {
                    newFilters.add(
                      FilterField(
                        exactMatch: filter.value.first.exactMatch,
                        filterType: filter.value.first.filterType,
                        field: filter.value.first.field,
                        value: filter.value.first.filterType ==
                                    FilterTypesFF.string ||
                                filter.value.first.filterType ==
                                    FilterTypesFF.stringList
                            ? filter.value.map((e) => e.value).toList()
                            : filter.value.first.value,
                      ),
                    );
                  }
                }
                widget.onFilterChanged(newFilters);
              },
              actionPercentageWidth: widget.tableActionPercentageWidth,
              frameWidth: constraints.maxWidth,
              frameHeight:
                  constraints.maxHeight - (topPanelHeight + _separator),
              tableActions: widget.tableActions,
              enableCopyButton: widget.enableCopyButton,
              selectedListCallback: widget.selectedListCallback,
              columns: widget.columns,
              title: widget.title,
              handleSelectedRow: (Map<String, dynamic>? rowData, int rowIndex) {
                if (widget.rowPressCallback != null) {
                  widget.rowPressCallback!(rowData);
                }
              },
            ),
          )
        ],
      );
    });
  }
}
